# -*- coding: utf-8 -*-
#
# Copyright © 2018-2019 Nick Bowler
#
# License GPLv3+: GNU General Public License version 3 or any later version.
# This is free software: you are free to change and redistribute it.
# There is NO WARRANTY, to the extent permitted by law.

PLUGIN_NAME = u"No remote plugins"
PLUGIN_AUTHOR = u"Nick Bowler"
PLUGIN_DESCRIPTION = u'''<p>This plugin disables querying the MusicBrainz
server for plugins.  This avoids network activity at startup and prevents
the options dialog from suggesting non-free plugins for installation.</p>
'''
PLUGIN_VERSION = "1.1"
PLUGIN_API_VERSIONS = ["1.0", "2.0"]
PLUGIN_LICENSE = "GPL-3.0-or-later"

from picard import (config, log, plugin)

try:
    from PyQt5 import QtCore
except (RuntimeError, ImportError):
    from PyQt4 import QtCore

import types

def modulename():
    return modulename.__module__[len("picard.plugins."):]

def repl_query(self, callback=None):
    pass

tagger = QtCore.QObject.tagger
def install_hooks():
    tagger.pluginmanager.query_available_plugins = \
        types.MethodType(repl_query, plugin.PluginManager)
    log.info("%s activated" % (modulename()))

if modulename() in config.setting["enabled_plugins"]:
    install_hooks()
else:
    log.debug("%s disabled in configuration" % (modulename()))
